# This spec file will build the package "R-base-gnome" (R with gnome
# support) if the macro %pkg is defined as "gnome", or R-base
# (R without gnome) if %pkg is defined as R-base.

%define version	1.3.0
%define release	2mdk
%define pkg	base

Summary: A language for data analysis and graphics
Name: R-%{pkg}
Version: %{version}
Release: %{release}
Source0: ftp://cran.r-project.org/pub/R/src/base/R-%{version}.tar.bz2
License: GPL
Group: Sciences/Mathematics
URL: http://www.r-project.org
Icon: logosm-trans.gif
Prefix: %{_prefix}
Requires: perl, sed
BuildRequires: gcc-g77, XFree86-devel, libjpeg, libpng, zlib, ncurses-devel
BuildRequires: tetex-dvips, tetex-latex, texinfo, tcl, tk
BuildRequires: readline-devel
Conflicts: R-contrib <= 1998.11.16
Conflicts: R-VR <= 5.3pl027
Obsoletes: R-gnome
BuildRoot: %{_tmppath}/%{name}-%{version}-root
ExcludeArch: ppc

%description
`GNU S' - A language and environment for statistical computing and
graphics. R is similar to S, which was developed at Bell Laboratories
by John Chambers et al. It provides a wide variety of statistical and
graphical techniques (linear and nonlinear modelling, statistical
tests, time series analysis, classification, clustering, ...).

R is designed as a true computer language with control-flow
constructions for iteration and alternation, and it allows users to
add additional functionality by defining new functions. For
computationally intensive tasks, C and Fortran code can be linked and
called at run time.

%prep
%setup -q -n R-%{version}

%build
export CFLAGS="$RPM_OPT_FLAGS -fno-fast-math"
export FFLAGS="$RPM_OPT_FLAGS -fno-fast-math"
if [ %pkg = "base-gnome" ]; then
   ./configure --prefix=$RPM_BUILD_ROOT%{_prefix} --with-gnome --with-mandir=%{_mandir}
else
   ./configure --prefix=$RPM_BUILD_ROOT%{_prefix} --with-mandir=%{_mandir}
fi
export DISPLAY=
%make
%make pdf
# DON'T comment "make check" below! If R doesn't pass the 'check' test
# then it is probably badly compiled, or there are problems with
# the compiler.
make check

%install
%makeinstall
mv doc/manual/*.pdf $RPM_BUILD_DIR/R-%{version} || :

# Remove latex versions of help pages
#
rm -rf $RPM_BUILD_ROOT%{_libdir}/R/library/*/latex/

# Fix location of R_HOME_DIR in shell wrapper
#
( cd $RPM_BUILD_ROOT%{_bindir}
  perl -i -pe "s@R_HOME_DIR=.*@R_HOME_DIR=%{_libdir}/R@" R )
( cd $RPM_BUILD_ROOT%{_libdir}/R/bin
  perl -i -pe "s@R_HOME_DIR=.*@R_HOME_DIR=%{_libdir}/R@" R )

# Remove package indices. They are rebuilt by the postinstall script.
#
rm -f $RPM_BUILD_ROOT%{_libdir}/R/doc/html/function.html \
    $RPM_BUILD_ROOT%{_libdir}/R/doc/html/packages.html \
    $RPM_BUILD_ROOT%{_libdir}/R/library/LibIndex

%files 
%defattr(-, root, root)
%{_bindir}/R
%{_mandir}/*/*
%{_libdir}/R
%doc AUTHORS BUGS COPYING COPYRIGHTS FAQ NEWS
%doc README RESOURCES THANKS VERSION Y2K
%doc R-data.pdf R-exts.pdf R-FAQ.pdf R-intro.pdf R-lang.pdf refman.pdf

%clean
rm -rf $RPM_BUILD_ROOT

%post
%{_bindir}/R CMD perl %{_libdir}/R/share/perl/build-help.pl --htmllist > /dev/null 2>&1
cat %{_libdir}/R/library/*/CONTENTS > %{_libdir}/R/doc/html/search/index.txt
# LibIndex is deprecated (remove eventually from previous versions)
rm -rf %{_libdir}/R/library/LibIndex

%preun 
if [ $1 = 0 ]; then
   rm -f %{_libdir}/R/doc/html/function.html \
	%{_libdir}/R/doc/html/packages.html \
	%{_libdir}/R/library/LibIndex
fi

%changelog
* Thu Aug 02 2001 Giuseppe Ghib <ghibo@mandrakesoft.coM> 1.3.0-2mdk
- removed LIBINDEX patch.

* Wed Jul 25 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.3.0-1mdk
- updated to release 1.3.0.

* Tue May 15 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.3-2mdk
- added readline-devel in BuildRequires.

* Sat May 05 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.3-1mdk
- updated to release 1.2.3 (bugfixes).

* Sat Apr 07 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.2-2mdk
- fixed a typo in configure.

* Tue Mar 08 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.2-1mdk
- updated to version 1.2.2.

* Sat Feb 17 2001 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.1-1mdk
- updated to version 1.2.1.
- changed lib/bin/maketitle.awk permission to non-executable.

* Fri Dec 22 2000 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.0-4mdk
- added PDF of Reference Manual.
- added tcl, tk in BuildRequires.

* Tue Dec 19 2000 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.0-3mdk
- removed stdout output in post scripts.

* Tue Dec 19 2000 David BAUDENS <baudens@mandrakesoft.com> 1.2.0-2mdk
- ExcludeArch: ppc

* Tue Dec 19 2000 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.2.0-1mdk
- new fresh release.

* Tue Dec 19 2000 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.1.1-3mdk
- fixed broken macros (aargh!).

* Sun Oct 28 2000 David BAUDENS <baudens@mandrakesoft.com> 1.1.1-2mdk
- Use %%make macro
- bzip2 patch

* Fri Sep 01 2000 Giuseppe Ghib <ghibo@mandrakesoft.com> 1.1.1-1mdk
- initial mandrake release.
- added BuildRequires.
- added -fno-fast-math, otherwise R doesn't passes the arith checks.
- switched order of make check and make pdf.

* Wed Aug 16 2000 Martyn Plummer <plummer@iarc.fr>
- R 1.1.1 released. Removed R-1.1.0-cofig.sub-alpha.patch since
  this version uses up to date config.sub.

* Fri Jun 16 2000 Martyn Plummer <plummer@iarc.fr>
- Added patch R-1.1.0-cofig.sub-alpha.patch from Naoki Takebayashi

* Thu Jun 15 2000 Martyn Plummer <plummer@iarc.fr>
- Removed dependencies on egcs egcs-g77

* Tue Feb 29 2000 Martyn Plummer <plummer@iarc.fr
- Changed the description to match
  http://developer.r-project.org/R-description-short.txt

* Mon Feb 28 2000 Martyn Plummer <plummer@iarc.fr>
- Added egcs, egcs-g77 and perl as requirements. People who want to install
  their own R packages need a working build environment.

* Fri Feb 11 2000 Martyn Plummer <plummer@iarc.fr>
- Remove latex versions of help pages, to save a bit of space.
- PDF files installed in top level doc directory.
- Included R-0.99.0-fixes patch for some serious bugs

* Tue Feb  8 2000 Martyn Plummer <plummer@iarc.fr>
- Added patch R-refman.patch which prevents building the reference manual

* Fri Feb  4 2000 Martyn Plummer <plummer@iarc.fr>
- Updated in preparation for R-0.99.0.
- Now install manual in pdf format.

* Wed Dec 15 1999 Martyn Plummer <plummer@iarc.fr>
- R-0.90.1. Removed Naoki's memory profile patch

* Fri Dec 3 1999 Tim Powers <timp@redhat.com>
- move configure into build section
- quiet scripts
- built for Powertools-6.2

* Mon Nov 29 1999 Martyn Plummer <plummer@iarc.fr>
- Added patch from Naoki to fix problem with memory profile.
  (will be folded in to next R version).

* Mon Nov 22 1999 Martyn Plummer <plummer@iarc.fr>
- R 0.90.0 Naoki's patch for FFT bug no longer necessary.
- Updated URL tag to www.r-project.org 

* Thu Oct 28 1999 Martyn Plummer <plummer@iarc.fr>
- RHCN is officially dead. Changed the Packager field
  back to my name and removed the Distribution field.

* Thu Oct 14 1999 Martyn Plummer <plummer@iarc.fr>
- Set CFLAGS and FFLAGS to be RPM_OPT_FLAGS. Thanks to
  Timothy H. Keitt <keitt@nceas.ucsb.edu>
- Simplified file list.

* Fri Oct 8 1999 Martyn Plummer <plummer@iarc.fr>
- Added patch from Naoki Takebayashi to fix FFT bug on Alpha
  (also found on Sparc).

* Tue Sep 7 1999 Martyn Plummer <plummer@iarc.fr>
  [R-base-0.65.0-1]
- RHOME is now R_HOME. Changed sed scripts accordingly.
- TASKS file is no longer in file list.
